@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2002-2013 Sourcefire, Inc.
 ** Copyright (C) 1998-2002 Martin Roesch <roesch@sourcefire.com>
 **
@@ -1785,6 +1785,8 @@ typedef struct _Packet
     uint8_t error_flags;        /* flags indicate checksum errors, bad TTLs, etc. */
     uint8_t encapsulated;
     uint8_t GTPencapsulated;
+    uint8_t GREencapsulated;
+    uint8_t IPnIPencapsulated;
     uint8_t non_ip_pkt;
     uint8_t next_layer;         /* index into layers for next encap */
 
