@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+** Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
 ** Copyright (C) 2005-2013 Sourcefire, Inc.
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -27,6 +27,7 @@
 #include <netinet/in.h>
 #include "str_search.h"
 #include "appInfoTable.h"
+#include "common_util.h"
 #include "detector_api.h"
 #include "httpCommon.h"
 #include "http_url_patterns.h"
@@ -1562,7 +1563,8 @@ tAppId scanCHP (PatternType ptype, char *buf, int buf_size, MatchedCHPAction *mp
                 break;
             if (!hsession->fflow)
             {
-                if (!(hsession->fflow = (fflow_info*)calloc(1,sizeof(fflow_info))))
+                if (!(hsession->fflow = (fflow_info*)_dpd.snortAlloc(1,
+                    sizeof(fflow_info), PP_APP_ID, PP_MEM_CATEGORY_SESSION)))
                 {
                     appidStaticConfig->chp_fflow_disabled = 1;
                     break;
@@ -1576,7 +1578,8 @@ tAppId scanCHP (PatternType ptype, char *buf, int buf_size, MatchedCHPAction *mp
                 break;
             if (!hsession->fflow)
             {
-                if (!(hsession->fflow = (fflow_info*)calloc(1,sizeof(fflow_info))))
+                if (!(hsession->fflow = (fflow_info*)_dpd.snortAlloc(1,
+                    sizeof(fflow_info), PP_APP_ID, PP_MEM_CATEGORY_SESSION)))
                 {
                     appidStaticConfig->chp_fflow_disabled = 1;
                     break;
@@ -1590,7 +1593,8 @@ tAppId scanCHP (PatternType ptype, char *buf, int buf_size, MatchedCHPAction *mp
                 break;
             if (!hsession->fflow)
             {
-                if (!(hsession->fflow = (fflow_info*)calloc(1,sizeof(fflow_info))))
+                if (!(hsession->fflow = (fflow_info*)_dpd.snortAlloc(1,
+                     sizeof(fflow_info), PP_APP_ID, PP_MEM_CATEGORY_SESSION)))
                 {
                     appidStaticConfig->chp_fflow_disabled = 1;
                     break;
@@ -1604,7 +1608,8 @@ tAppId scanCHP (PatternType ptype, char *buf, int buf_size, MatchedCHPAction *mp
                 break;
             if (!hsession->fflow)
             {
-                if (!(hsession->fflow = (fflow_info*)calloc(1,sizeof(fflow_info))))
+                if (!(hsession->fflow = (fflow_info*)_dpd.snortAlloc(1,
+                    sizeof(fflow_info), PP_APP_ID, PP_MEM_CATEGORY_SESSION)))
                 {
                     appidStaticConfig->chp_fflow_disabled = 1;
                     break;
@@ -1618,7 +1623,8 @@ tAppId scanCHP (PatternType ptype, char *buf, int buf_size, MatchedCHPAction *mp
                 break;
             if (!hsession->fflow)
             {
-                if (!(hsession->fflow = (fflow_info*)calloc(1,sizeof(fflow_info))))
+                if (!(hsession->fflow = (fflow_info*)_dpd.snortAlloc(1,
+                    sizeof(fflow_info), PP_APP_ID, PP_MEM_CATEGORY_SESSION)))
                 {
                     appidStaticConfig->chp_fflow_disabled = 1;
                     break;
@@ -1632,7 +1638,8 @@ tAppId scanCHP (PatternType ptype, char *buf, int buf_size, MatchedCHPAction *mp
                 break;
             if (!hsession->fflow)
             {
-                if (!(hsession->fflow = (fflow_info*)calloc(1,sizeof(fflow_info))))
+                if (!(hsession->fflow = (fflow_info*)_dpd.snortAlloc(1,
+                    sizeof(fflow_info), PP_APP_ID, PP_MEM_CATEGORY_SESSION)))
                 {
                     appidStaticConfig->chp_fflow_disabled = 1;
                     break;
