@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * Copyright (C) 2014-2019 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -32,6 +32,8 @@
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
+#include "ftpp_include.h"
+#include "memory_stats.h"
 
 //#define MDEBUG
 
@@ -40,13 +42,13 @@ static unsigned msize=0;
 void * xmalloc(size_t byteSize)
 {
 #ifdef MDEBUG
-   int * data = (int*) malloc( byteSize + 4 );
+   int * data = (int*)_dpd.snortAlloc(1, byteSize+4,
+                                      PP_FTPTELNET, PP_MEM_CATEGORY_CONFIG);
    unsigned m = msize;
 
-   if(data)memset(data,0,byteSize+4);
 #else
-   int * data = (int*) malloc( byteSize );
-   if(data)memset(data,0,byteSize);
+   int * data = (int*)_dpd.snortAlloc(1, byteSize,
+                                      PP_FTPTELNET, PP_MEM_CATEGORY_CONFIG);
 #endif
 
    if( data == NULL )
@@ -74,7 +76,7 @@ void * xmalloc(size_t byteSize)
 #endif
 }
 
-void xfree( void * p )
+void xfree( void * p , int n )
 {
 #ifdef MDEBUG
    unsigned m = msize;
@@ -82,11 +84,11 @@ void xfree( void * p )
    q--;
    msize -= *q;
 
-   free(q);
+   _dpd.snortFree(q, n+4, PP_FTPTELNET, PP_MEM_CATEGORY_CONFIG);
 
 #else
 
-   free(p);
+   _dpd.snortFree(p, n, PP_FTPTELNET, PP_MEM_CATEGORY_CONFIG);
 
 #endif
 
