@@ -1,7 +1,7 @@
 /*
  * spp_ftptelnet.c
  *
- * Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2004-2013 Sourcefire, Inc.
  * Steven A. Sturges <ssturges@sourcefire.com>
  * Daniel J. Roelker <droelker@sourcefire.com>
@@ -45,6 +45,7 @@
 #include <string.h>
 #include <stdio.h>
 #include <sys/types.h>
+#include <time.h> 
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -71,6 +72,7 @@
 #endif
 
 #include "reg_test.h"
+#include "memory_stats.h"
 
 const int MAJOR_VERSION = 1;
 const int MINOR_VERSION = 2;
@@ -135,6 +137,7 @@ static int FtpTelnetReloadVerify(struct _SnortConfig *, void *);
 static void * FtpTelnetReloadSwap(struct _SnortConfig *, void *);
 static void FtpTelnetReloadSwapFree(void *);
 #endif
+int ftptelnet_print_mem_stats(FILE *, char*, PreprocMemInfo *);
 
 extern char *maxToken;
 
@@ -327,8 +330,10 @@ static void FTPTelnetInit(struct _SnortConfig *sc, char *args)
                 *_dpd.config_file, *_dpd.config_line);
         }
 
-        pPolicyConfig =
-            (FTPTELNET_GLOBAL_CONF *)calloc(1, sizeof(FTPTELNET_GLOBAL_CONF));
+        pPolicyConfig = (FTPTELNET_GLOBAL_CONF *)_dpd.snortAlloc(1,
+                                                  sizeof(FTPTELNET_GLOBAL_CONF),
+                                                  PP_FTPTELNET,
+                                                  PP_MEM_CATEGORY_CONFIG);
 
         if (pPolicyConfig == NULL)
         {
@@ -480,6 +485,7 @@ void SetupFTPTelnet(void)
 #ifdef DUMP_BUFFER
     _dpd.registerBufferTracer(getFTPTelnetBuffers, FTPTELNET_BUFFER_DUMP_FUNC);
 #endif
+    _dpd.registerMemoryStatsFunc(PP_FTPTELNET, ftptelnet_print_mem_stats);
 }
 
 static void FTPTelnetReset(int signal, void *data)
@@ -511,6 +517,72 @@ static void FTPTelnetStats(int exiting)
                 ftp_telnet_stats.heap_memory);
 }
 
+int ftptelnet_print_mem_stats(FILE *fd, char* buffer, PreprocMemInfo *meminfo)
+{
+    time_t curr_time = time(NULL);
+    int len = 0;
+    size_t total_heap_memory = meminfo[PP_MEM_CATEGORY_SESSION].used_memory 
+                              + meminfo[PP_MEM_CATEGORY_CONFIG].used_memory; 
+    if (fd)
+    {
+        len = fprintf(fd, ","STDu64","STDu64","STDu64"" 
+                       ","STDu64","STDu64","STDu64""
+                       ",%lu,%u,%u,%lu,%u,%u,%lu"
+                       , ftp_telnet_stats.ftp_sessions
+                       , ftp_telnet_stats.max_ftp_sessions
+                       , ftp_telnet_stats.ftp_data_sessions
+                       , ftp_telnet_stats.max_ftp_data_sessions
+                       , ftp_telnet_stats.telnet_sessions
+                       , ftp_telnet_stats.max_telnet_sessions
+                       , meminfo[PP_MEM_CATEGORY_SESSION].used_memory
+                       , meminfo[PP_MEM_CATEGORY_SESSION].num_of_alloc
+                       , meminfo[PP_MEM_CATEGORY_SESSION].num_of_free
+                       , meminfo[PP_MEM_CATEGORY_CONFIG].used_memory
+                       , meminfo[PP_MEM_CATEGORY_CONFIG].num_of_alloc
+                       , meminfo[PP_MEM_CATEGORY_CONFIG].num_of_free
+                       , total_heap_memory);
+       return len;
+    }
+    if (buffer)
+    {
+        len = snprintf(buffer, CS_STATS_BUF_SIZE,
+                       "\n\nMemory Statistics for FTPTelnet at: %s\n"
+                       "FTPTelnet Preprocessor Statistics:\n"
+                       "       Current active FTP sessions :  "STDu64"\n"
+                       "       Max concurrent FTP sessions :  "STDu64"\n"
+                       "           Total FTP Data sessions :  "STDu64"\n"
+                       "  Max concurrent FTP Data sessions :  "STDu64"\n"
+                       "    Current active Telnet sessions :  "STDu64"\n"
+                       "    Max concurrent Telnet sessions :  "STDu64"\n"
+                       , ctime(&curr_time)
+                       , ftp_telnet_stats.ftp_sessions
+                       , ftp_telnet_stats.max_ftp_sessions
+                       , ftp_telnet_stats.ftp_data_sessions
+                       , ftp_telnet_stats.max_ftp_data_sessions
+                       , ftp_telnet_stats.telnet_sessions
+                       , ftp_telnet_stats.max_telnet_sessions);
+    }
+    else 
+    {
+        _dpd.logMsg("\n");
+        _dpd.logMsg("Memory Statistics of FTPTelnet at: %s\n",
+                    ctime(&curr_time));
+        _dpd.logMsg("       Current active FTP sessions :    "STDu64"\n",
+                    ftp_telnet_stats.ftp_sessions);
+        _dpd.logMsg("       Max concurrent FTP sessions :    "STDu64"\n",
+                    ftp_telnet_stats.max_ftp_sessions);
+        _dpd.logMsg("           Total FTP Data sessions :    "STDu64"\n",
+                    ftp_telnet_stats.ftp_data_sessions);
+        _dpd.logMsg("  Max concurrent FTP Data sessions :    "STDu64"\n",
+                    ftp_telnet_stats.max_ftp_data_sessions);
+        _dpd.logMsg("    Current active Telnet sessions :    "STDu64"\n",
+                    ftp_telnet_stats.telnet_sessions);
+        _dpd.logMsg("    Max concurrent Telnet sessions :    "STDu64"\n",
+                    ftp_telnet_stats.max_telnet_sessions);
+    }
+    return len;
+}
+
 #ifdef SNORT_RELOAD
 static void _FtpTelnetReload(struct _SnortConfig *sc, tSfPolicyUserContextId ftp_telnet_swap_config, char *args)
 {
@@ -556,8 +628,10 @@ static void _FtpTelnetReload(struct _SnortConfig *sc, tSfPolicyUserContextId ftp
                 *_dpd.config_file, *_dpd.config_line);
         }
 
-        pPolicyConfig =
-            (FTPTELNET_GLOBAL_CONF *)calloc(1, sizeof(FTPTELNET_GLOBAL_CONF));
+        pPolicyConfig = (FTPTELNET_GLOBAL_CONF *)_dpd.snortAlloc(1,
+                                                  sizeof(FTPTELNET_GLOBAL_CONF),
+                                                  PP_FTPTELNET,
+                                                  PP_MEM_CATEGORY_CONFIG);
 
         if (pPolicyConfig == NULL)
         {
