@@ -1,6 +1,6 @@
 /****************************************************************************
  * 
- * Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2011-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -35,7 +35,7 @@
 
 void POP_GetEOL(const uint8_t *, const uint8_t *, const uint8_t **, const uint8_t **);
 void POP_DecodeType(const char *start, int length, bool cnt_xf);
-int POP_Print_Mem_Stats(char *buffer);
+int POP_Print_Mem_Stats(FILE *fd, char *buffer, PreprocMemInfo *meminfo);
 
 #ifdef DEBUG_MSGS
 const char * POP_PrintBuffer(SFSnortPacket *);
