@@ -16,7 +16,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
- * Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * Author: Andy  Mullican
@@ -54,16 +54,47 @@
 #include "sf_dynamic_preprocessor.h"
 #include "sf_snort_packet.h"
 
+#include "memory_stats.h"
+
 extern SMTP *smtp_ssn;
 extern char smtp_normalizing;
 extern MemPool *smtp_mime_mempool;
 extern MemPool *smtp_mempool;
 
-int SMTP_Print_Mem_Stats(char *buffer)
+int SMTP_Print_Mem_Stats(FILE *fd, char *buffer, PreprocMemInfo *meminfo)
 {
     time_t curr_time = time(NULL);
-    
-    return snprintf(buffer, CS_STATS_BUF_SIZE, "\n\nMemory Statistics of SMTP on: %s\n"
+    int len = 0;
+ 
+
+    if (fd)
+    {   
+        len = fprintf(fd, ",%lu,%lu,%lu"
+                 ",%lu,%u,%u"
+                 ",%lu,%u,%u,%lu"
+                 , smtp_stats.sessions
+                 , smtp_stats.max_conc_sessions
+                 , smtp_stats.cur_sessions
+                 , meminfo[PP_MEM_CATEGORY_SESSION].used_memory
+                 , meminfo[PP_MEM_CATEGORY_SESSION].num_of_alloc
+                 , meminfo[PP_MEM_CATEGORY_SESSION].num_of_free
+                 , meminfo[PP_MEM_CATEGORY_CONFIG].used_memory
+                 , meminfo[PP_MEM_CATEGORY_CONFIG].num_of_alloc
+                 , meminfo[PP_MEM_CATEGORY_CONFIG].num_of_free
+                 , meminfo[PP_MEM_CATEGORY_SESSION].used_memory +
+                   meminfo[PP_MEM_CATEGORY_CONFIG].used_memory);
+
+        return len;
+
+    } 
+
+    if (buffer) {
+        /*
+         * Old buffer output for control socket comm,
+         * like via, "show snort preprocessor-memory-usage"
+         * CLI preserved as is
+         */
+        len = snprintf(buffer, CS_STATS_BUF_SIZE, "\n\nMemory Statistics of SMTP on: %s\n"
              "SMTP Session Statistics:\n"
              "       Total Sessions seen: " STDu64 "\n"
              "   Max concurrent sessions: " STDu64 "\n"
@@ -87,6 +118,28 @@ int SMTP_Print_Mem_Stats(char *buffer)
              , (smtp_mempool) ? smtp_mempool->used_memory : 0
              , ((smtp_mime_mempool) ? (smtp_mime_mempool->max_memory) : 0) +
                              ((smtp_mempool) ? (smtp_mempool->max_memory) : 0));
+
+        len += PopulateMemStatsBuffTrailer(buffer+len, len, meminfo);
+
+    } else {
+
+        _dpd.logMsg("SMTP Preprocessor Statistics\n");
+        _dpd.logMsg("  Total sessions                : %lu \n", smtp_stats.sessions);
+        _dpd.logMsg("  Max concurrent sessions       : %lu \n", smtp_stats.max_conc_sessions);
+        _dpd.logMsg("  Current sessions              : %lu \n", smtp_stats.cur_sessions);
+        _dpd.logMsg("  SMPT Session ");
+        _dpd.logMsg("     Used Memory  :%14lu", meminfo[PP_MEM_CATEGORY_SESSION].used_memory);
+        _dpd.logMsg("     No of Allocs :%14u", meminfo[PP_MEM_CATEGORY_SESSION].num_of_alloc);
+        _dpd.logMsg("     No of Frees  :%14u", meminfo[PP_MEM_CATEGORY_SESSION].num_of_free);
+        _dpd.logMsg("  SMTP Config ");
+        _dpd.logMsg("     Used Memory  :%14lu", meminfo[PP_MEM_CATEGORY_CONFIG].used_memory);
+        _dpd.logMsg("     No of Allocs :%14u", meminfo[PP_MEM_CATEGORY_CONFIG].num_of_alloc);
+        _dpd.logMsg("     No of Frees  :%14u", meminfo[PP_MEM_CATEGORY_CONFIG].num_of_free);
+        _dpd.logMsg("   Total memory used :%14lu", meminfo[PP_MEM_CATEGORY_SESSION].used_memory +
+                                                   meminfo[PP_MEM_CATEGORY_CONFIG].used_memory);
+
+    }
+    return len;
 }
 
 void SMTP_GetEOL(const uint8_t *ptr, const uint8_t *end,
