@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2005-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -252,7 +252,8 @@ void SMTP_InitCmds(SMTPConfig *config)
         return;
 
     /* add one to CMD_LAST for NULL entry */
-    config->cmds = (SMTPToken *)_dpd.snortAlloc(CMD_LAST + 1, sizeof(SMTPToken), PP_SMTP, 1);
+    config->cmds = (SMTPToken *)_dpd.snortAlloc(CMD_LAST + 1, sizeof(SMTPToken), PP_SMTP,
+                                     PP_MEM_CATEGORY_CONFIG);
     if (config->cmds == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => failed to allocate memory for smtp "
@@ -276,7 +277,8 @@ void SMTP_InitCmds(SMTPConfig *config)
     }
 
     /* initialize memory for command searches */
-    config->cmd_search = (SMTPSearch *)_dpd.snortAlloc(CMD_LAST, sizeof(SMTPSearch), PP_SMTP, 1);
+    config->cmd_search = (SMTPSearch *)_dpd.snortAlloc(CMD_LAST, sizeof(SMTPSearch), PP_SMTP,
+                                            PP_MEM_CATEGORY_CONFIG);
     if (config->cmd_search == NULL)
     {
         DynamicPreprocessorFatalMessage("%s(%d) => failed to allocate memory for smtp "
@@ -386,7 +388,8 @@ static SMTP * SMTP_GetNewSession(SFSnortPacket *p, tSfPolicyId policy_id)
 
     DEBUG_WRAP(DebugMessage(DEBUG_SMTP, "Creating new session data structure\n"););
 
-    ssn = (SMTP *)_dpd.snortAlloc(1, sizeof(SMTP), PP_SMTP, 0);
+    ssn = (SMTP *)_dpd.snortAlloc(1, sizeof(SMTP), PP_SMTP,
+                       PP_MEM_CATEGORY_SESSION);
     if (ssn == NULL)
     {
         DynamicPreprocessorFatalMessage("Failed to allocate SMTP session data\n");
@@ -410,7 +413,7 @@ static SMTP * SMTP_GetNewSession(SFSnortPacket *p, tSfPolicyId policy_id)
             }
             smtp_stats.log_memcap_exceeded++;
         }
-	_dpd.snortFree(ssn, sizeof(*ssn), PP_SMTP, 0);
+	_dpd.snortFree(ssn, sizeof(*ssn), PP_SMTP, PP_MEM_CATEGORY_SESSION);
         return NULL;
     }
     _dpd.sessionAPI->set_application_data(p->stream_session, PP_SMTP,
@@ -599,23 +602,26 @@ static void SMTP_SessionFree(void *session_data)
     if(smtp->mime_ssn.decode_state != NULL)
     {
         mempool_free(smtp_mime_mempool, smtp->mime_ssn.decode_bkt);
-	_dpd.snortFree(smtp->mime_ssn.decode_state, sizeof(Email_DecodeState), PP_SMTP, 0);
+	_dpd.snortFree(smtp->mime_ssn.decode_state, sizeof(Email_DecodeState), PP_SMTP,
+             PP_MEM_CATEGORY_SESSION);
     }
 
     if(smtp->mime_ssn.log_state != NULL)
     {
         mempool_free(smtp_mempool, smtp->mime_ssn.log_state->log_hdrs_bkt);
-	_dpd.snortFree(smtp->mime_ssn.log_state, sizeof(MAIL_LogState), PP_SMTP, 0);
+	_dpd.snortFree(smtp->mime_ssn.log_state, sizeof(MAIL_LogState), PP_SMTP,
+             PP_MEM_CATEGORY_SESSION);
     }
 
     if(smtp->auth_name != NULL)
     {
-	_dpd.snortFree(smtp->auth_name, sizeof(*(smtp->auth_name)), PP_SMTP, 0);
+	_dpd.snortFree(smtp->auth_name, sizeof(*(smtp->auth_name)), PP_SMTP,
+             PP_MEM_CATEGORY_SESSION);
     }
     if ( ssl_cb )
         ssl_cb->session_free(smtp->flow_id);
 
-    _dpd.snortFree(smtp, sizeof(*smtp), PP_SMTP, 0);
+    _dpd.snortFree(smtp, sizeof(*smtp), PP_SMTP, PP_MEM_CATEGORY_SESSION);
     if(smtp_stats.conc_sessions)
         smtp_stats.conc_sessions--;
 
@@ -657,21 +663,23 @@ void SMTP_FreeConfig(SMTPConfig *config)
         SMTPToken *tmp = config->cmds;
 
         for (; tmp->name != NULL; tmp++)
-	    _dpd.snortFree(tmp->name, sizeof(*(tmp->name)), PP_SMTP, 1);
+            _dpd.snortFree(tmp->name, sizeof(*(tmp->name)), PP_SMTP, PP_MEM_CATEGORY_CONFIG);
 
-	_dpd.snortFree(config->cmds, sizeof(*(config->cmds)), PP_SMTP, 1);
+        _dpd.snortFree(config->cmds, sizeof(*(config->cmds)), PP_SMTP, PP_MEM_CATEGORY_CONFIG);
     }
 
     if (config->cmd_config != NULL)
-	_dpd.snortFree(config->cmd_config, sizeof(*(config->cmd_config)), PP_SMTP, 1);
+        _dpd.snortFree(config->cmd_config, sizeof(*(config->cmd_config)), PP_SMTP,
+             PP_MEM_CATEGORY_CONFIG);
 
     if (config->cmd_search_mpse != NULL)
         _dpd.searchAPI->search_instance_free(config->cmd_search_mpse);
 
     if (config->cmd_search != NULL)
-	_dpd.snortFree(config->cmd_search, sizeof(*(config->cmd_search)), PP_SMTP, 1);
+        _dpd.snortFree(config->cmd_search, sizeof(*(config->cmd_search)), PP_SMTP,
+             PP_MEM_CATEGORY_CONFIG);
 
-    _dpd.snortFree(config, sizeof(*config), PP_SMTP, 1);
+    _dpd.snortFree(config, sizeof(*config), PP_SMTP, PP_MEM_CATEGORY_CONFIG);
 }
 
 
@@ -759,7 +767,8 @@ static bool SMTP_IsAuthChanged(const uint8_t *start_ptr, const uint8_t *end_ptr)
             auth_changed = true;
     }
     else
-          smtp_ssn->auth_name = _dpd.snortAlloc(1, sizeof(*(smtp_ssn->auth_name)), PP_SMTP, 0);
+          smtp_ssn->auth_name = _dpd.snortAlloc(1, sizeof(*(smtp_ssn->auth_name)), PP_SMTP,
+                                     PP_MEM_CATEGORY_SESSION);
 
     /* save the current authentication mechanism*/
     if (!smtp_ssn->auth_name)
@@ -1683,20 +1692,23 @@ void SnortSMTP(SFSnortPacket *p)
          if(smtp_ssn->mime_ssn.decode_state != NULL)
          {
              mempool_free(smtp_mime_mempool, smtp_ssn->mime_ssn.decode_bkt);
-	     _dpd.snortFree(smtp_ssn->mime_ssn.decode_state, sizeof(Email_DecodeState), PP_SMTP, 0);
+	     _dpd.snortFree(smtp_ssn->mime_ssn.decode_state, sizeof(Email_DecodeState), PP_SMTP,
+                  PP_MEM_CATEGORY_SESSION);
              smtp_ssn->mime_ssn.decode_state = NULL;
          }
 
          if(smtp_ssn->mime_ssn.log_state != NULL)
          {
              mempool_free(smtp_mempool, smtp_ssn->mime_ssn.log_state->log_hdrs_bkt);
-	     _dpd.snortFree(smtp_ssn->mime_ssn.log_state, sizeof(MAIL_LogState), PP_SMTP, 0);
+	     _dpd.snortFree(smtp_ssn->mime_ssn.log_state, sizeof(MAIL_LogState), PP_SMTP,
+                  PP_MEM_CATEGORY_SESSION);
              smtp_ssn->mime_ssn.log_state = NULL;
          }
 
          if(smtp_ssn->auth_name != NULL)
          {
-	     _dpd.snortFree(smtp_ssn->auth_name, sizeof(*(smtp_ssn->auth_name)), PP_SMTP, 0);
+	     _dpd.snortFree(smtp_ssn->auth_name, sizeof(*(smtp_ssn->auth_name)), PP_SMTP,
+                  PP_MEM_CATEGORY_SESSION);
              smtp_ssn->auth_name = NULL;
          }
     }
