@@ -1,5 +1,5 @@
 /*
- ** Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ ** Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  ** Copyright (C) 2013-2013 Sourcefire, Inc.
  **
  ** This program is free software; you can redistribute it and/or modify
@@ -38,11 +38,13 @@
 #include "file_config.h"
 #include "file_stats.h"
 #include "file_service.h"
+#include "memory_stats.h"
 
 #include <unistd.h>
 #include <string.h>
 #include <fcntl.h>
 #include <sys/types.h>
+#include <time.h>
 
 SafeMemPool *file_mempool = NULL;
 File_Capture_Stats file_capture_stats;
@@ -135,7 +137,7 @@ static void* _init_file_mempool(int64_t max_file_mem, int64_t block_size)
 
     max_files = max_file_mem_in_bytes / block_size ;
 
-    file_mempool = (SafeMemPool *)calloc(1, sizeof(SafeMemPool));
+    file_mempool = (SafeMemPool *)SnortPreprocAlloc(1, sizeof(SafeMemPool), PP_FILE, PP_MEM_CATEGORY_MEMPOOL);
 
     if ((!file_mempool)||
             (safe_mempool_init(file_mempool, max_files, block_size) != 0))
@@ -644,8 +646,66 @@ void file_caputure_close(void)
 
     if (safe_mempool_destroy(file_mempool) == 0)
     {
-        free(file_mempool);
+        SnortPreprocFree(file_mempool, sizeof(SafeMemPool), PP_FILE, PP_MEM_CATEGORY_MEMPOOL);
         file_mempool = NULL;
     }
 
 }
+
+int FilePrintMemStats(FILE *fd, char* buffer, PreprocMemInfo *meminfo)
+{
+    time_t curr_time = time(NULL);
+    int len = 0;
+    size_t total_heap_memory = meminfo[PP_MEM_CATEGORY_SESSION].used_memory 
+                              + meminfo[PP_MEM_CATEGORY_CONFIG].used_memory 
+                              + meminfo[PP_MEM_CATEGORY_MEMPOOL].used_memory;
+    if (fd)
+    {
+        len = fprintf(fd, ",%lu,%u,%u"
+                      ",%lu,%u,%u"
+                      ",%lu,%u,%u,%lu"
+                      , meminfo[PP_MEM_CATEGORY_SESSION].used_memory
+                      , meminfo[PP_MEM_CATEGORY_SESSION].num_of_alloc
+                      , meminfo[PP_MEM_CATEGORY_SESSION].num_of_free
+                      , meminfo[PP_MEM_CATEGORY_CONFIG].used_memory
+                      , meminfo[PP_MEM_CATEGORY_CONFIG].num_of_alloc
+                      , meminfo[PP_MEM_CATEGORY_CONFIG].num_of_free
+                      , meminfo[PP_MEM_CATEGORY_MEMPOOL].used_memory
+                      , meminfo[PP_MEM_CATEGORY_MEMPOOL].num_of_alloc
+                      , meminfo[PP_MEM_CATEGORY_MEMPOOL].num_of_free
+                      , total_heap_memory);
+       return len;
+   }
+   if (buffer)
+   {
+       len = snprintf(buffer, CS_STATS_BUF_SIZE, "\n\nMemory Statistics for File at: %s\n"
+       "Total buffers allocated:           "FMTu64("-10")" \n" 
+       "Total buffers freed:               "FMTu64("-10")" \n" 
+       "Total buffers released:            "FMTu64("-10")" \n"
+       "Total file mempool:                "FMTu64("-10")" \n" 
+       "Total allocated file mempool:      "FMTu64("-10")" \n"
+       "Total freed file mempool:          "FMTu64("-10")" \n"
+       "Total released file mempool:       "FMTu64("-10")" \n"
+       , ctime(&curr_time)
+       , file_capture_stats.file_buffers_allocated_total
+       , file_capture_stats.file_buffers_freed_total
+       , file_capture_stats.file_buffers_released_total
+       , (file_mempool)?(file_mempool->total):0
+       , (file_mempool)?(safe_mempool_allocated(file_mempool)):0
+       , (file_mempool)?(safe_mempool_freed(file_mempool)):0
+       , (file_mempool)?(safe_mempool_released(file_mempool)):0);
+    }
+    else
+    {
+       LogMessage("\n");
+       LogMessage("Memory Statistics for File at:%s\n" , ctime(&curr_time));
+       LogMessage("Total buffers allocated:           "FMTu64("-10")" \n", file_capture_stats.file_buffers_allocated_total);
+       LogMessage("Total buffers freed:               "FMTu64("-10")" \n", file_capture_stats.file_buffers_freed_total);
+       LogMessage("Total buffers released:            "FMTu64("-10")" \n", file_capture_stats.file_buffers_released_total);
+       LogMessage("Total file mempool:                "FMTu64("-10")" \n", (file_mempool)?(file_mempool->total):0);
+       LogMessage("Total allocated file mempool:      "FMTu64("-10")" \n", (file_mempool)?(safe_mempool_allocated(file_mempool)):0);
+       LogMessage("Total freed file mempool:          "FMTu64("-10")" \n", (file_mempool)?(safe_mempool_freed(file_mempool)):0);
+       LogMessage("Total released file mempool:       "FMTu64("-10")" \n", (file_mempool)?(safe_mempool_released(file_mempool)):0);
+    }
+    return len;
+}
