@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2008-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 #include "parser.h"
 #include "file_resume_block.h"
 #include "file_config.h"
+#include "memory_stats.h"
 
 #ifdef REG_TEST
 #include "file_stats.h"
@@ -49,7 +50,7 @@ static inline void file_segment_free(FileCache *fileCache, FileSegment* file_seg
 			fileCache->status.segment_mem_in_use = 0;
 	}
 
-	free(file_segment);
+	SnortPreprocFree(file_segment, sizeof(FileSegment), PP_FILE, PP_MEM_CATEGORY_SESSION);
 }
 
 static inline void file_segments_free (FileEntry *file_entry)
@@ -77,7 +78,7 @@ static inline void file_entry_free(FileEntry *file_entry)
     {
         DEBUG_WRAP(DebugMessage(DEBUG_FILE,
                               "File name: %s released (%p)\n", file_entry->file_name, file_entry->file_name));
-        free(file_entry->file_name);
+        SnortPreprocFree(file_entry->file_name, file_entry->file_name_size, PP_FILE, PP_MEM_CATEGORY_SESSION);
         file_entry->file_name = NULL;
         file_entry->file_name_size = 0;
     }
@@ -241,7 +242,7 @@ static inline FileSegment* file_segment_alloc (FileCache *fileCache,
 
     fileCache->status.segment_mem_in_use += size;
 
-    ss = (FileSegment*) SnortAlloc(size);
+    ss = (FileSegment*) SnortPreprocAlloc(1, size, PP_FILE, PP_MEM_CATEGORY_SESSION);
     ss->segment_size = size;
     ss->size = data_size;
     ss->offset = offset;
@@ -391,7 +392,7 @@ static inline int _process_one_file_segment (void* p, FileEntry *fileEntry,
         {
             if((fileEntry->context->file_state.sig_state == FILE_SIG_FLUSH) && fileEntry->context->sha256)
             {
-                free(fileEntry->context->sha256);
+                SnortPreprocFree(fileEntry->context->sha256, SHA256_HASH_SIZE, PP_FILE, PP_MEM_CATEGORY_SESSION);
                 fileEntry->context->sha256 = NULL;
             } 
             fileEntry->context->smb_unknown_file_size = false;
@@ -403,7 +404,7 @@ static inline int _process_one_file_segment (void* p, FileEntry *fileEntry,
         Packet *pkt = (Packet *)p;
         if((fileEntry->context->file_state.sig_state == FILE_SIG_FLUSH) && fileEntry->context && fileEntry->context->sha256)
         {
-            free(fileEntry->context->sha256);
+            SnortPreprocFree(fileEntry->context->sha256, SHA256_HASH_SIZE, PP_FILE, PP_MEM_CATEGORY_SESSION);
             fileEntry->context->sha256 = NULL;
         }
         if(pkt->packet_flags & PKT_PDU_TAIL)
@@ -461,7 +462,7 @@ FileCache *file_cache_create(uint64_t memcap, uint32_t cleanup_files)
     /* Half for file segment, half for file context tracking*/
     max_files = get_max_files_from_memcap(memcap - file_segment_memcap);
 
-    fileCache = SnortAlloc( sizeof( *fileCache ) );
+    fileCache = SnortPreprocAlloc(1, sizeof(*fileCache), PP_FILE, PP_MEM_CATEGORY_SESSION);
     if( fileCache )
     {
         fileCache->max_files = max_files;
@@ -493,7 +494,7 @@ void file_cache_free( FileCache *fileCache )
     if (fileCache)
     {
         sfxhash_delete(fileCache->hashTable);
-        free(fileCache);
+        SnortPreprocFree(fileCache, sizeof(FileCache), PP_FILE, PP_MEM_CATEGORY_SESSION);
     }
 }
 
@@ -524,7 +525,7 @@ void *file_cache_update_entry (FileCache *fileCache, void* p, uint64_t file_id,
         if (fileEntry->file_name && fileEntry->file_name != file_name)
         {
             FILE_DEBUG("File name: %s released (%p)", fileEntry->file_name,fileEntry->file_name);
-            free(fileEntry->file_name);
+            SnortPreprocFree(fileEntry->file_name, fileEntry->file_name_size, PP_FILE, PP_MEM_CATEGORY_SESSION);
         }
         fileEntry->file_name = file_name;
         fileEntry->file_name_size = file_name_size;
