@@ -1,7 +1,7 @@
 /*
  **
  **
- **  Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ **  Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  **  Copyright (C) 2012-2013 Sourcefire, Inc.
  **
  **  This program is free software; you can redistribute it and/or modify
@@ -38,6 +38,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include "sf_sechash.h"
+#include "memory_stats.h"
 
 #include "util.h"
 #include "file_capture.h"
@@ -139,13 +140,14 @@ void file_signature_sha256(FileContext* context, uint8_t* file_data,
     {
     case SNORT_FILE_START:
         if (!context->file_signature_context)
-            context->file_signature_context = SnortAlloc(sizeof(SHA256CONTEXT));
+            context->file_signature_context = SnortPreprocAlloc(1, sizeof(SHA256CONTEXT), PP_FILE, PP_MEM_CATEGORY_SESSION);
+
         SHA256INIT((SHA256CONTEXT *)context->file_signature_context);
         SHA256UPDATE((SHA256CONTEXT *)context->file_signature_context, file_data, data_size);
         if(context->file_state.sig_state == FILE_SIG_FLUSH)
         {
             static uint8_t file_signature_context_backup[sizeof(SHA256CONTEXT)];
-            context->sha256 = SnortAlloc(SHA256_HASH_SIZE);
+            context->sha256 = SnortPreprocAlloc(1, SHA256_HASH_SIZE, PP_FILE, PP_MEM_CATEGORY_SESSION);
             memcpy(file_signature_context_backup, context->file_signature_context, sizeof(SHA256CONTEXT));
 
             SHA256FINAL(context->sha256, (SHA256CONTEXT *)context->file_signature_context);
@@ -154,13 +156,13 @@ void file_signature_sha256(FileContext* context, uint8_t* file_data,
         break;
     case SNORT_FILE_MIDDLE:
         if (!context->file_signature_context)
-            context->file_signature_context = SnortAlloc(sizeof(SHA256CONTEXT));
+            context->file_signature_context = SnortPreprocAlloc(1, sizeof(SHA256CONTEXT), PP_FILE, PP_MEM_CATEGORY_SESSION);
         SHA256UPDATE((SHA256CONTEXT *)context->file_signature_context, file_data, data_size);
         if(context->file_state.sig_state == FILE_SIG_FLUSH)
         {
             static uint8_t file_signature_context_backup[sizeof(SHA256CONTEXT)];
             if(!context->sha256)
-                context->sha256 = SnortAlloc(SHA256_HASH_SIZE);
+                context->sha256 = SnortPreprocAlloc(1, SHA256_HASH_SIZE, PP_FILE, PP_MEM_CATEGORY_SESSION);
             memcpy(file_signature_context_backup, context->file_signature_context, sizeof(SHA256CONTEXT));
 
             SHA256FINAL(context->sha256, (SHA256CONTEXT *)context->file_signature_context);
@@ -169,22 +171,22 @@ void file_signature_sha256(FileContext* context, uint8_t* file_data,
         break;
     case SNORT_FILE_END:
         if (!context->file_signature_context)
-            context->file_signature_context = SnortAlloc(sizeof(SHA256CONTEXT));
+            context->file_signature_context = SnortPreprocAlloc(1, sizeof(SHA256CONTEXT), PP_FILE, PP_MEM_CATEGORY_SESSION);
         if (context->processed_bytes == 0)
             SHA256INIT((SHA256CONTEXT *)context->file_signature_context);
         SHA256UPDATE((SHA256CONTEXT *)context->file_signature_context, file_data, data_size);
         if(!context->sha256)
-            context->sha256 = SnortAlloc(SHA256_HASH_SIZE);
+            context->sha256 = SnortPreprocAlloc(1, SHA256_HASH_SIZE, PP_FILE, PP_MEM_CATEGORY_SESSION);
         SHA256FINAL(context->sha256, (SHA256CONTEXT *)context->file_signature_context);
         context->file_state.sig_state = FILE_SIG_DONE;
         break;
     case SNORT_FILE_FULL:
         if (!context->file_signature_context)
-            context->file_signature_context = SnortAlloc(sizeof (SHA256CONTEXT));
+            context->file_signature_context = SnortPreprocAlloc(1, sizeof(SHA256CONTEXT), PP_FILE, PP_MEM_CATEGORY_SESSION);
         SHA256INIT((SHA256CONTEXT *)context->file_signature_context);
         SHA256UPDATE((SHA256CONTEXT *)context->file_signature_context, file_data, data_size);
         if(!context->sha256)
-            context->sha256 = SnortAlloc(SHA256_HASH_SIZE);
+            context->sha256 = SnortPreprocAlloc(1, SHA256_HASH_SIZE, PP_FILE, PP_MEM_CATEGORY_SESSION);
         SHA256FINAL(context->sha256, (SHA256CONTEXT *)context->file_signature_context);
         context->file_state.sig_state = FILE_SIG_DONE;
         break;
@@ -197,20 +199,20 @@ void file_signature_sha256(FileContext* context, uint8_t* file_data,
 
 FileContext *file_context_create(void)
 {
-    FileContext *context = (FileContext *)SnortAlloc(sizeof(*context));
+    FileContext *context = (FileContext *)SnortPreprocAlloc(1, sizeof(*context), PP_FILE, PP_MEM_CATEGORY_SESSION);
     return (context);
 }
 
 static inline void cleanDynamicContext (FileContext *context)
 {
     if (context->file_signature_context)
-        free(context->file_signature_context);
+        SnortPreprocFree(context->file_signature_context, sizeof(SHA256CONTEXT), PP_FILE, PP_MEM_CATEGORY_SESSION);
     if(context->sha256)
-        free(context->sha256);
+        SnortPreprocFree(context->sha256, SHA256_HASH_SIZE, PP_FILE, PP_MEM_CATEGORY_SESSION);
     if(context->file_capture)
         file_capture_stop(context);
     if(context->file_name && context->file_name_saved)
-        free(context->file_name);
+        SnortPreprocFree(context->file_name, context->file_name_size, PP_FILE, PP_MEM_CATEGORY_SESSION);
 }
 
 void file_context_reset(FileContext *context)
@@ -226,7 +228,7 @@ void file_context_free(void *ctx)
     if (!context || context->attached_file_entry)
         return;
     cleanDynamicContext(context);
-    free(context);
+    SnortPreprocFree(context, sizeof(FileContext), PP_FILE, PP_MEM_CATEGORY_SESSION);
 }
 
 /*File properties*/
@@ -243,8 +245,8 @@ void file_name_set (FileContext *context, uint8_t *file_name, uint32_t name_size
     if (save_in_context)
     {
         if (context->file_name && context->file_name_saved)
-            free(context->file_name);
-        name = SnortAlloc(name_size);
+            SnortPreprocFree(context->file_name, sizeof(name_size), PP_FILE, PP_MEM_CATEGORY_SESSION);
+        name = SnortPreprocAlloc(1, name_size, PP_FILE, PP_MEM_CATEGORY_SESSION);
         memcpy(name, file_name, name_size);
         context->file_name_saved = true;
     }
