@@ -1,6 +1,6 @@
 /****************************************************************************
  *
- * Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2003-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -195,7 +195,9 @@ static HI_EVENT_INFO server_event_info[HI_EO_SERVER_EVENT_NUM] = {
     {HI_EO_SERVER_INVALID_CONTENT_RANGE_UNIT_FMT, HI_EO_MED_PRIORITY,
         HI_EO_SERVER_INVALID_CONTENT_RANGE_UNIT_FMT_STR},
     {HI_EO_SERVER_RANGE_FIELD_ERROR, HI_EO_MED_PRIORITY,
-        HI_EO_SERVER_RANGE_FIELD_ERROR_STR}
+        HI_EO_SERVER_RANGE_FIELD_ERROR_STR},
+    {HI_EO_SERVER_NON_RANGE_GET_PARTIAL_METHOD, HI_EO_MED_PRIORITY,
+        HI_EO_SERVER_NON_RANGE_GET_PARTIAL_METHOD_STR}
 };
 
 /*
