@@ -1,7 +1,7 @@
 /* $Id$ */
 /****************************************************************************
  *
- * Copyright (C) 2014-2020 Cisco and/or its affiliates. All rights reserved.
+ * Copyright (C) 2014-2021 Cisco and/or its affiliates. All rights reserved.
  * Copyright (C) 2011-2013 Sourcefire, Inc.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -69,6 +69,7 @@
 #include "stream_api.h"
 #include "snort_debug.h"
 #include "snort_httpinspect.h"
+#include "memory_stats.h"
 
 #ifdef DEBUG_MSGS
 #define HI_TRACE     // define for state trace
@@ -643,7 +644,8 @@ static bool hi_fsm_compile (void)
     hi_fsm_size = max + extra;
     assert(hi_fsm_size < TBD);  // using uint8_t for Cell.next and Hi5State.fsm
 
-    hi_fsm = malloc(hi_fsm_size*sizeof(*hi_fsm));
+    hi_fsm = SnortPreprocAlloc(1, hi_fsm_size*sizeof(*hi_fsm), PP_HTTPINSPECT, 
+                  PP_MEM_CATEGORY_SESSION);
     if ( hi_fsm == NULL )
     {
         DEBUG_WRAP(DebugMessage(DEBUG_STREAM_PAF, "Unable to allocate memory for hi_fsm."););
@@ -1368,7 +1370,8 @@ static PAF_Status hi_paf (
     {
         // beware - we allocate here but s5 calls free() directly
         // so no pointers allowed
-        hip = calloc(1, sizeof(Hi5State));
+        hip = SnortPreprocAlloc(1, sizeof(Hi5State), PP_HTTPINSPECT, 
+                   PP_MEM_CATEGORY_SESSION);
 
         if ( !hip )
         {
@@ -1561,6 +1564,12 @@ int hi_paf_register_port (
     return 0;
 }
 
+static void hi_paf_cleanup(void *pafData)
+{
+    if (pafData)
+        SnortPreprocFree(pafData, sizeof(Hi5State), PP_HTTPINSPECT, PP_MEM_CATEGORY_SESSION);
+}
+
 int hi_paf_register_service (
     struct _SnortConfig *sc, uint16_t service, bool client, bool server, tSfPolicyId pid, bool auto_on)
 {
@@ -1574,11 +1583,15 @@ int hi_paf_register_service (
         return -1;
 
     if ( client )
+    {
         hi_paf_id = stream_api->register_paf_service(sc, pid, service, true, hi_paf, auto_on);
-
+        stream_api->register_paf_free(hi_paf_id, hi_paf_cleanup);
+    }
     if ( server )
+    {
         hi_paf_id = stream_api->register_paf_service(sc, pid, service, false, hi_paf, auto_on);
-
+        stream_api->register_paf_free(hi_paf_id, hi_paf_cleanup);
+    }
     return 0;
 }
 
@@ -1603,7 +1616,8 @@ bool hi_paf_init (uint32_t cap)
 
 void hi_paf_term (void)
 {
-    free(hi_fsm);
+    SnortPreprocFree(hi_fsm, hi_fsm_size*sizeof(*hi_fsm), PP_HTTPINSPECT, 
+         PP_MEM_CATEGORY_SESSION);
     DEBUG_WRAP(DebugMessage(DEBUG_STREAM_PAF,
         "%s: calls=%u, bytes=%u\n",  __FUNCTION__,
         hi_paf_calls, hi_paf_bytes);)
